@@ -30,6 +30,7 @@ from .paginator import (
     DescribeJobDefinitionsPaginator,
     DescribeJobQueuesPaginator,
     ListJobsPaginator,
+    ListSchedulingPoliciesPaginator,
 )
 from .type_defs import (
     ArrayPropertiesTypeDef,
@@ -40,14 +41,18 @@ from .type_defs import (
     ContainerPropertiesTypeDef,
     CreateComputeEnvironmentResponseTypeDef,
     CreateJobQueueResponseTypeDef,
+    CreateSchedulingPolicyResponseTypeDef,
     DescribeComputeEnvironmentsResponseTypeDef,
     DescribeJobDefinitionsResponseTypeDef,
     DescribeJobQueuesResponseTypeDef,
     DescribeJobsResponseTypeDef,
+    DescribeSchedulingPoliciesResponseTypeDef,
+    FairsharePolicyTypeDef,
     JobDependencyTypeDef,
     JobTimeoutTypeDef,
     KeyValuesPairTypeDef,
     ListJobsResponseTypeDef,
+    ListSchedulingPoliciesResponseTypeDef,
     ListTagsForResourceResponseTypeDef,
     NodeOverridesTypeDef,
     NodePropertiesTypeDef,
@@ -83,7 +88,7 @@ class Exceptions:
 
 class BatchClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.11/reference/services/batch.html#Batch.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.10/reference/services/batch.html#Batch.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/client.html)
     """
 
@@ -99,7 +104,7 @@ class BatchClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.11/reference/services/batch.html#Batch.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.10/reference/services/batch.html#Batch.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/client.html#can_paginate)
         """
 
@@ -107,7 +112,7 @@ class BatchClient(BaseClient):
         """
         Cancels a job in an Batch job queue.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.11/reference/services/batch.html#Batch.Client.cancel_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.10/reference/services/batch.html#Batch.Client.cancel_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/client.html#cancel_job)
         """
 
@@ -117,6 +122,7 @@ class BatchClient(BaseClient):
         computeEnvironmentName: str,
         type: CETypeType,
         state: CEStateType = ...,
+        unmanagedvCpus: int = ...,
         computeResources: "ComputeResourceTypeDef" = ...,
         serviceRole: str = ...,
         tags: Mapping[str, str] = ...
@@ -124,7 +130,7 @@ class BatchClient(BaseClient):
         """
         Creates an Batch compute environment.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.11/reference/services/batch.html#Batch.Client.create_compute_environment)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.10/reference/services/batch.html#Batch.Client.create_compute_environment)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/client.html#create_compute_environment)
         """
 
@@ -135,20 +141,35 @@ class BatchClient(BaseClient):
         priority: int,
         computeEnvironmentOrder: Sequence["ComputeEnvironmentOrderTypeDef"],
         state: JQStateType = ...,
+        schedulingPolicyArn: str = ...,
         tags: Mapping[str, str] = ...
     ) -> CreateJobQueueResponseTypeDef:
         """
         Creates an Batch job queue.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.11/reference/services/batch.html#Batch.Client.create_job_queue)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.10/reference/services/batch.html#Batch.Client.create_job_queue)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/client.html#create_job_queue)
         """
 
+    def create_scheduling_policy(
+        self,
+        *,
+        name: str,
+        fairsharePolicy: "FairsharePolicyTypeDef" = ...,
+        tags: Mapping[str, str] = ...
+    ) -> CreateSchedulingPolicyResponseTypeDef:
+        """
+        Creates an Batch scheduling policy.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.10/reference/services/batch.html#Batch.Client.create_scheduling_policy)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/client.html#create_scheduling_policy)
+        """
+
     def delete_compute_environment(self, *, computeEnvironment: str) -> Dict[str, Any]:
         """
         Deletes an Batch compute environment.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.11/reference/services/batch.html#Batch.Client.delete_compute_environment)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.10/reference/services/batch.html#Batch.Client.delete_compute_environment)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/client.html#delete_compute_environment)
         """
 
@@ -156,15 +177,23 @@ class BatchClient(BaseClient):
         """
         Deletes the specified job queue.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.11/reference/services/batch.html#Batch.Client.delete_job_queue)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.10/reference/services/batch.html#Batch.Client.delete_job_queue)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/client.html#delete_job_queue)
         """
 
+    def delete_scheduling_policy(self, *, arn: str) -> Dict[str, Any]:
+        """
+        Deletes the specified scheduling policy.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.10/reference/services/batch.html#Batch.Client.delete_scheduling_policy)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/client.html#delete_scheduling_policy)
+        """
+
     def deregister_job_definition(self, *, jobDefinition: str) -> Dict[str, Any]:
         """
         Deregisters an Batch job definition.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.11/reference/services/batch.html#Batch.Client.deregister_job_definition)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.10/reference/services/batch.html#Batch.Client.deregister_job_definition)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/client.html#deregister_job_definition)
         """
 
@@ -178,7 +207,7 @@ class BatchClient(BaseClient):
         """
         Describes one or more of your compute environments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.11/reference/services/batch.html#Batch.Client.describe_compute_environments)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.10/reference/services/batch.html#Batch.Client.describe_compute_environments)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/client.html#describe_compute_environments)
         """
 
@@ -194,7 +223,7 @@ class BatchClient(BaseClient):
         """
         Describes a list of job definitions.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.11/reference/services/batch.html#Batch.Client.describe_job_definitions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.10/reference/services/batch.html#Batch.Client.describe_job_definitions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/client.html#describe_job_definitions)
         """
 
@@ -204,7 +233,7 @@ class BatchClient(BaseClient):
         """
         Describes one or more of your job queues.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.11/reference/services/batch.html#Batch.Client.describe_job_queues)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.10/reference/services/batch.html#Batch.Client.describe_job_queues)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/client.html#describe_job_queues)
         """
 
@@ -212,10 +241,20 @@ class BatchClient(BaseClient):
         """
         .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.11/reference/services/batch.html#Batch.Client.describe_jobs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.10/reference/services/batch.html#Batch.Client.describe_jobs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/client.html#describe_jobs)
         """
 
+    def describe_scheduling_policies(
+        self, *, arns: Sequence[str]
+    ) -> DescribeSchedulingPoliciesResponseTypeDef:
+        """
+        Describes one or more of your scheduling policies.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.10/reference/services/batch.html#Batch.Client.describe_scheduling_policies)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/client.html#describe_scheduling_policies)
+        """
+
     def generate_presigned_url(
         self,
         ClientMethod: str,
@@ -226,7 +265,7 @@ class BatchClient(BaseClient):
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.11/reference/services/batch.html#Batch.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.10/reference/services/batch.html#Batch.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/client.html#generate_presigned_url)
         """
 
@@ -244,15 +283,25 @@ class BatchClient(BaseClient):
         """
         Returns a list of Batch jobs.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.11/reference/services/batch.html#Batch.Client.list_jobs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.10/reference/services/batch.html#Batch.Client.list_jobs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/client.html#list_jobs)
         """
 
+    def list_scheduling_policies(
+        self, *, maxResults: int = ..., nextToken: str = ...
+    ) -> ListSchedulingPoliciesResponseTypeDef:
+        """
+        Returns a list of Batch scheduling policies.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.10/reference/services/batch.html#Batch.Client.list_scheduling_policies)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/client.html#list_scheduling_policies)
+        """
+
     def list_tags_for_resource(self, *, resourceArn: str) -> ListTagsForResourceResponseTypeDef:
         """
         Lists the tags for an Batch resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.11/reference/services/batch.html#Batch.Client.list_tags_for_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.10/reference/services/batch.html#Batch.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/client.html#list_tags_for_resource)
         """
 
@@ -262,6 +311,7 @@ class BatchClient(BaseClient):
         jobDefinitionName: str,
         type: JobDefinitionTypeType,
         parameters: Mapping[str, str] = ...,
+        schedulingPriority: int = ...,
         containerProperties: "ContainerPropertiesTypeDef" = ...,
         nodeProperties: "NodePropertiesTypeDef" = ...,
         retryStrategy: "RetryStrategyTypeDef" = ...,
@@ -273,7 +323,7 @@ class BatchClient(BaseClient):
         """
         Registers an Batch job definition.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.11/reference/services/batch.html#Batch.Client.register_job_definition)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.10/reference/services/batch.html#Batch.Client.register_job_definition)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/client.html#register_job_definition)
         """
 
@@ -283,6 +333,8 @@ class BatchClient(BaseClient):
         jobName: str,
         jobQueue: str,
         jobDefinition: str,
+        shareIdentifier: str = ...,
+        schedulingPriorityOverride: int = ...,
         arrayProperties: "ArrayPropertiesTypeDef" = ...,
         dependsOn: Sequence["JobDependencyTypeDef"] = ...,
         parameters: Mapping[str, str] = ...,
@@ -296,7 +348,7 @@ class BatchClient(BaseClient):
         """
         Submits an Batch job from a job definition.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.11/reference/services/batch.html#Batch.Client.submit_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.10/reference/services/batch.html#Batch.Client.submit_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/client.html#submit_job)
         """
 
@@ -304,7 +356,7 @@ class BatchClient(BaseClient):
         """
         Associates the specified tags to a resource with the specified `resourceArn`.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.11/reference/services/batch.html#Batch.Client.tag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.10/reference/services/batch.html#Batch.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/client.html#tag_resource)
         """
 
@@ -312,7 +364,7 @@ class BatchClient(BaseClient):
         """
         Terminates a job in a job queue.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.11/reference/services/batch.html#Batch.Client.terminate_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.10/reference/services/batch.html#Batch.Client.terminate_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/client.html#terminate_job)
         """
 
@@ -320,7 +372,7 @@ class BatchClient(BaseClient):
         """
         Deletes specified tags from an Batch resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.11/reference/services/batch.html#Batch.Client.untag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.10/reference/services/batch.html#Batch.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/client.html#untag_resource)
         """
 
@@ -329,13 +381,14 @@ class BatchClient(BaseClient):
         *,
         computeEnvironment: str,
         state: CEStateType = ...,
+        unmanagedvCpus: int = ...,
         computeResources: "ComputeResourceUpdateTypeDef" = ...,
         serviceRole: str = ...
     ) -> UpdateComputeEnvironmentResponseTypeDef:
         """
         Updates an Batch compute environment.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.11/reference/services/batch.html#Batch.Client.update_compute_environment)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.10/reference/services/batch.html#Batch.Client.update_compute_environment)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/client.html#update_compute_environment)
         """
 
@@ -344,22 +397,33 @@ class BatchClient(BaseClient):
         *,
         jobQueue: str,
         state: JQStateType = ...,
+        schedulingPolicyArn: str = ...,
         priority: int = ...,
         computeEnvironmentOrder: Sequence["ComputeEnvironmentOrderTypeDef"] = ...
     ) -> UpdateJobQueueResponseTypeDef:
         """
         Updates a job queue.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.11/reference/services/batch.html#Batch.Client.update_job_queue)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.10/reference/services/batch.html#Batch.Client.update_job_queue)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/client.html#update_job_queue)
         """
 
+    def update_scheduling_policy(
+        self, *, arn: str, fairsharePolicy: "FairsharePolicyTypeDef" = ...
+    ) -> Dict[str, Any]:
+        """
+        Updates a scheduling policy.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.10/reference/services/batch.html#Batch.Client.update_scheduling_policy)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/client.html#update_scheduling_policy)
+        """
+
     @overload
     def get_paginator(
         self, operation_name: Literal["describe_compute_environments"]
     ) -> DescribeComputeEnvironmentsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.11/reference/services/batch.html#Batch.Paginator.DescribeComputeEnvironments)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.10/reference/services/batch.html#Batch.Paginator.DescribeComputeEnvironments)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/paginators.html#describecomputeenvironmentspaginator)
         """
 
@@ -368,7 +432,7 @@ class BatchClient(BaseClient):
         self, operation_name: Literal["describe_job_definitions"]
     ) -> DescribeJobDefinitionsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.11/reference/services/batch.html#Batch.Paginator.DescribeJobDefinitions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.10/reference/services/batch.html#Batch.Paginator.DescribeJobDefinitions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/paginators.html#describejobdefinitionspaginator)
         """
 
@@ -377,13 +441,22 @@ class BatchClient(BaseClient):
         self, operation_name: Literal["describe_job_queues"]
     ) -> DescribeJobQueuesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.11/reference/services/batch.html#Batch.Paginator.DescribeJobQueues)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.10/reference/services/batch.html#Batch.Paginator.DescribeJobQueues)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/paginators.html#describejobqueuespaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_jobs"]) -> ListJobsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.11/reference/services/batch.html#Batch.Paginator.ListJobs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.10/reference/services/batch.html#Batch.Paginator.ListJobs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/paginators.html#listjobspaginator)
         """
+
+    @overload
+    def get_paginator(
+        self, operation_name: Literal["list_scheduling_policies"]
+    ) -> ListSchedulingPoliciesPaginator:
+        """
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.10/reference/services/batch.html#Batch.Paginator.ListSchedulingPolicies)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/paginators.html#listschedulingpoliciespaginator)
+        """
