@@ -38,6 +38,7 @@ __all__ = (
     "JobDefinitionTypeType",
     "JobStatusType",
     "ListJobsPaginatorName",
+    "ListSchedulingPoliciesPaginatorName",
     "LogDriverType",
     "PlatformCapabilityType",
     "ResourceTypeType",
@@ -67,6 +68,7 @@ JobStatusType = Literal[
     "FAILED", "PENDING", "RUNNABLE", "RUNNING", "STARTING", "SUBMITTED", "SUCCEEDED"
 ]
 ListJobsPaginatorName = Literal["list_jobs"]
+ListSchedulingPoliciesPaginatorName = Literal["list_scheduling_policies"]
 LogDriverType = Literal["awslogs", "fluentd", "gelf", "journald", "json-file", "splunk", "syslog"]
 PlatformCapabilityType = Literal["EC2", "FARGATE"]
 ResourceTypeType = Literal["GPU", "MEMORY", "VCPU"]
@@ -84,6 +86,7 @@ ServiceName = Literal[
     "apigatewaymanagementapi",
     "apigatewayv2",
     "appconfig",
+    "appconfigdata",
     "appflow",
     "appintegrations",
     "application-autoscaling",
@@ -152,6 +155,7 @@ ServiceName = Literal[
     "dlm",
     "dms",
     "docdb",
+    "drs",
     "ds",
     "dynamodb",
     "dynamodbstreams",
@@ -258,6 +262,7 @@ ServiceName = Literal[
     "mgh",
     "mgn",
     "migrationhub-config",
+    "migrationhubstrategy",
     "mobile",
     "mq",
     "mturk",
@@ -291,6 +296,7 @@ ServiceName = Literal[
     "redshift",
     "redshift-data",
     "rekognition",
+    "resiliencehub",
     "resource-groups",
     "resourcegroupstaggingapi",
     "robomaker",
@@ -360,5 +366,9 @@ ServiceName = Literal[
     "xray",
 ]
 PaginatorName = Literal[
-    "describe_compute_environments", "describe_job_definitions", "describe_job_queues", "list_jobs"
+    "describe_compute_environments",
+    "describe_job_definitions",
+    "describe_job_queues",
+    "list_jobs",
+    "list_scheduling_policies",
 ]
